@@ -14,11 +14,13 @@
 
 """Shared implementation of connections to API servers."""
 
+import collections
 import json
 import platform
 import warnings
 
 from pkg_resources import get_distribution
+from six.moves import collections_abc
 from six.moves.urllib.parse import urlencode
 
 from google.api_core.client_info import ClientInfo
@@ -46,6 +48,8 @@ The '_EXTRA_HEADERS' class-level attribute is deprecated.  Please use
 'extra_headers' instead.
 """
 
+_DEFAULT_TIMEOUT = 60  # in seconds
+
 
 class Connection(object):
     """A generic connection to Google Cloud Platform.
@@ -209,8 +213,18 @@ class JSONConnection(Connection):
         )
 
         query_params = query_params or {}
-        if query_params:
-            url += "?" + urlencode(query_params, doseq=True)
+
+        if isinstance(query_params, collections_abc.Mapping):
+            query_params = query_params.copy()
+        else:
+            query_params_dict = collections.defaultdict(list)
+            for key, value in query_params:
+                query_params_dict[key].append(value)
+            query_params = query_params_dict
+
+        query_params.setdefault("prettyPrint", "false")
+
+        url += "?" + urlencode(query_params, doseq=True)
 
         return url
 
@@ -222,7 +236,7 @@ class JSONConnection(Connection):
         content_type=None,
         headers=None,
         target_object=None,
-        timeout=None,
+        timeout=_DEFAULT_TIMEOUT,
     ):
         """A low level method to send a request to the API.
 
@@ -253,7 +267,7 @@ class JSONConnection(Connection):
 
         :type timeout: float or tuple
         :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response. By default, the method waits indefinitely.
+            for the server response.
 
             Can also be passed as a tuple (connect_timeout, read_timeout).
             See :meth:`requests.Session.request` documentation for details.
@@ -276,7 +290,7 @@ class JSONConnection(Connection):
         )
 
     def _do_request(
-        self, method, url, headers, data, target_object, timeout=None
+        self, method, url, headers, data, target_object, timeout=_DEFAULT_TIMEOUT
     ):  # pylint: disable=unused-argument
         """Low-level helper:  perform the actual API request over HTTP.
 
@@ -301,7 +315,7 @@ class JSONConnection(Connection):
 
         :type timeout: float or tuple
         :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response. By default, the method waits indefinitely.
+            for the server response.
 
             Can also be passed as a tuple (connect_timeout, read_timeout).
             See :meth:`requests.Session.request` documentation for details.
@@ -325,7 +339,7 @@ class JSONConnection(Connection):
         api_version=None,
         expect_json=True,
         _target_object=None,
-        timeout=None,
+        timeout=_DEFAULT_TIMEOUT,
     ):
         """Make a request over the HTTP transport to the API.
 
@@ -382,7 +396,7 @@ class JSONConnection(Connection):
 
         :type timeout: float or tuple
         :param timeout: (optional) The amount of time, in seconds, to wait
-            for the server response. By default, the method waits indefinitely.
+            for the server response.
 
             Can also be passed as a tuple (connect_timeout, read_timeout).
             See :meth:`requests.Session.request` documentation for details.
